OC.L10N.register(
    "impress",
    {
    "Documentation" : "Hjálparskjöl",
    "No Impress files are found in your ownCloud. Please upload a .impress file." : "Engar Impress skrár fundust í ownCloud uppsetningu þinni. Vinsamlegast settu inn .impress skrá.",
    "Name" : "Nafn",
    "Size" : "Stærð",
    "Date" : "Dagsetning"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
